FocusState

Enum FocusState 

pub enum FocusState {
    Active,
    ActiveParent,
    Captured,
    Inactive,
}
Focus state of a focus target node.

This mirrors Jetpack Compose’s FocusState enum which tracks whether a node is focused, has a focused child, or is inactive.

Variants



Active

The focusable component is currently active (i.e. it receives key events).



ActiveParent

One of the descendants of the focusable component is Active.



Captured

The focusable component is currently active (has focus), and is in a state where it does not want to give up focus. (Eg. a text field with an invalid phone number).



Inactive

The focusable component does not receive any key events. (ie it is not active, nor are any of its descendants active).

Implementations

Source

impl FocusState

pub fn is_focused(self) -> bool

Returns whether the component is focused (Active or Captured).

pub fn has_focus(self) -> bool

Returns whether this node or any descendant has focus.

pub fn is_captured(self) -> bool

Returns whether focus is captured.