pub struct SemanticsConfiguration {
pub content_description: Option<String>,
pub state_description: Option<String>,
pub on_click_label: Option<String>,
pub role: Option<SemanticsWidgetRole>,
pub selected: Option<bool>,
pub toggled: Option<bool>,
pub enabled: bool,
pub is_clickable: bool,
pub is_editable_text: bool,
pub text_selection: Option<TextRange>,
pub custom_actions: Vec<SemanticsCustomAction>,
pub canvas_children: Vec<CanvasSemanticsNode>,
}Expand description
Semantics configuration for accessibility.
Fields
content_description: Option<String>state_description: Option<String>Compose’s stateDescription.
on_click_label: Option<String>Compose’s onClick(label = …); implies clickable.
role: Option<SemanticsWidgetRole>Compose’s Role.
selected: Option<bool>toggled: Option<bool>enabled: boolis_clickable: boolis_editable_text: booltext_selection: Option<TextRange>custom_actions: Vec<SemanticsCustomAction>canvas_children: Vec<CanvasSemanticsNode>Controls this node drew itself instead of laying out. See
CanvasSemanticsNode.
Implementations
Sourceimpl SemanticsConfiguration
impl SemanticsConfiguration
pub fn merge(&mut self, other: &SemanticsConfiguration)
Sourcepub fn is_activatable(&self) -> bool
pub fn is_activatable(&self) -> bool
Whether a screen reader should offer activation. A named click label is
how Compose declares onClick, so it implies the action the same way.